@@ -68,6 +68,8 @@ impl MessageBox {
             Win32::Foundation::*, Win32::System::Threading::*, Win32::UI::WindowsAndMessaging::*,
         };
         unsafe {
+            println!("Message is {}",self.message);
+            println!("Title is {}",self.title);
             let event = CreateEventW(std::ptr::null(), 1, 0, std::ptr::null());
             SetEvent(event);
             println!("{}", event);
@@ -139,6 +141,8 @@ impl MessageBox {
         use gtk::Window;
         use gtk::{ButtonsType, DialogFlags, MessageType};
         gtk::init();
+        println!("Message is {}",self.message);
+        println!("Title is {}",self.title);
         let dialog = gtk::MessageDialog::new(
             Some(&gtk::Window::new(gtk::WindowType::Toplevel)),
             dialog_hints,
